@@ -17,21 +17,43 @@ import numpy as n, sys, _deconv
 # Find smallest representable # > 0 for setting clip level
 lo_clip_lev = n.finfo(n.float).tiny 
 
-def clean1d(im, ker, mdl=None, gain=.1, maxiter=10000, tol=1e-3):
-    """Perform 1 dimensional deconvolution using the CLEAN algorithm."""
+def clean(im, ker, mdl=None, gain=.1, maxiter=10000, tol=1e-3, verbose=False):
+    """This standard Hoegbom clean deconvolution algorithm operates on the 
+    assumption that the image is composed of point sources.  This makes it a 
+    poor choice for images with distributed flux.  In each iteration, a point 
+    is added to the model at the location of the maximum residual, with a 
+    fraction (specified by 'gain') of the magnitude.  The convolution of that 
+    point is removed from the residual, and the process repeats.  Termination 
+    happens after 'maxiter' iterations, or when the clean loops starts 
+    increasing the magnitude of the residual.  This implementation can handle 
+    1 and 2 dimensional data that is real valued or complex.
+    gain: The fraction of a residual used in each iteration.  If this is too
+        low, clean takes unnecessarily long.  If it is too high, clean does
+        a poor job of deconvolving."""
     if mdl is None:
         mdl = n.zeros_like(im)
         res = im.copy()
     else:
         mdl = mdl.copy()
-        res = im - n.fft.ifft(n.fft.fft(mdl) * n.fft.fft(ker)).astype(im.dtype)
-    mdl, iter = _deconv.clean1d(res,ker,mdl,gain=gain,maxiter=maxiter,tol=tol)
+        if len(mdl.shape) == 1:
+            res = im - n.fft.ifft(n.fft.fft(mdl) * \
+                                  n.fft.fft(ker)).astype(im.dtype)
+        elif len(mdl.shape) == 2:
+            res = im - n.fft.ifft2(n.fft.fft2(mdl) * \
+                                   n.fft.fft2(ker)).astype(im.dtype)
+        else: raise ValueError('Number of dimensions != 1 or 2')
+    iter = _deconv.clean(res, ker, mdl,
+            gain=gain, maxiter=maxiter, tol=tol, verbose=int(verbose))
     score = n.sqrt(n.average(n.abs(res)**2))
     info = {'success':iter > 0 and iter < maxiter, 'tol':tol}
     if iter < 0: info.update({'term':'divergence', 'iter':-iter})
     elif iter < maxiter: info.update({'term':'tol', 'iter':iter})
     else: info.update({'term':'maxiter', 'iter':iter})
     info.update({'res':res, 'score':score})
+    if verbose:
+        print 'Term Condition:', info['term']
+        print 'Iterations:', info['iter']
+        print 'Score:', info['score']
     return mdl, info
 
 def recenter(a, c):
@@ -42,63 +64,60 @@ def recenter(a, c):
     a2 = n.concatenate([a1[:,c[1]:], a1[:,:c[1]]], axis=1)
     return a2
 
-def clean(im, ker, mdl=None, gain=.2, maxiter=10000, chkiter=100, tol=1e-3,
-        lower=lo_clip_lev, upper=n.Inf, verbose=False):
-    """This standard Hoegbom clean deconvolution algorithm operates on the 
-    assumption that the image is composed of point sources.  This makes it a 
-    poor choice for images with distributed flux.  In each iteration, a point 
-    is added to the model at the location of the maximum residual, with a 
-    fraction (specified by 'gain') of the magnitude.  The convolution of that 
-    point is removed from the residual, and the process repeats.  Termination 
-    happens after 'maxiter' iterations, or when the clean loops starts 
-    increasing the magnitude of the residual.
-    gain: The fraction of a residual used in each iteration.  If this is too
-        low, clean takes unnecessarily long.  If it is too high, clean does
-        a poor job of deconvolving.
-    chkiter: The number of iterations between when clean checks if the 
-        residual is increasing."""
-    dim = im.shape[1]
-    q = n.sqrt((ker**2).sum())
-    G = q / gain
-    if mdl is None: mdl = n.zeros_like(im)
-    # Get the starting residual
-    inv_ker = n.fft.fft2(ker)
-    dif = im - n.fft.ifft2(n.fft.fft2(mdl) * inv_ker).real
-    score = n.sqrt(n.average(dif**2))
-    a0 = None
-    n_mdl, n_dif = mdl.copy(), dif.copy()
-    info = {'success':True, 'term':'maxiter', 'tol':tol}
-    # Begin the clean loop
-    for i in range(maxiter):
-        # Rather than perform a convolution each loop, we'll just subtract
-        # from the residual a scaled kernel centered on the point just added,
-        # and to avoid recentering the kernel each time (because clean often
-        # chooses the same point over and over), we'll buffer the previous one.
-        a = n.argmax(n_dif)
-        if a != a0:
-            a0 = a
-            rec_ker = recenter(ker, (-a/dim, -a%dim))
-        v = n_dif.flat[a] / G
-        n_mdl.flat[a] += v
-        n_dif -= v * rec_ker
-        # Check in on how clean is progressing.  Potenially terminate.
-        if i % chkiter == 0:
-            import pylab
-            pylab.imshow(n_dif)
-            pylab.show()
-            # Mystery: why does clean to worse when exact dif is computed?
-            #n_mdl = n_mdl.clip(lower, upper)
-            #n_dif = im - n.fft.ifft2(n.fft.fft2(mdl) * inv_ker).real
-            n_score = n.sqrt(n.average(n_dif**2))
-            if verbose:
-                print 'Step %d:' % i, 'score %f,' % n_score, 'best %f' % score
-            if n_score - score > score * tol:
-                n_mdl, n_dif = mdl, dif
-                info['term'] = 'tol'
-                break
-            score,mdl,dif = n_score, n_mdl.copy(), n_dif.copy()
-    info.update({'res':n_dif, 'score': score, 'iter':i+1})
-    return n_mdl, info
+#def clean(im, ker, mdl=None, gain=.2, maxiter=10000, chkiter=100, tol=1e-3,
+#        lower=lo_clip_lev, upper=n.Inf, verbose=False):
+#    """This standard Hoegbom clean deconvolution algorithm operates on the 
+#    assumption that the image is composed of point sources.  This makes it a 
+#    poor choice for images with distributed flux.  In each iteration, a point 
+#    is added to the model at the location of the maximum residual, with a 
+#    fraction (specified by 'gain') of the magnitude.  The convolution of that 
+#    point is removed from the residual, and the process repeats.  Termination 
+#    happens after 'maxiter' iterations, or when the clean loops starts 
+#    increasing the magnitude of the residual.
+#    gain: The fraction of a residual used in each iteration.  If this is too
+#        low, clean takes unnecessarily long.  If it is too high, clean does
+#        a poor job of deconvolving.
+#    chkiter: The number of iterations between when clean checks if the 
+#        residual is increasing."""
+#    dim = im.shape[1]
+#    q = n.sqrt((ker**2).sum())
+#    G = q / gain
+#    if mdl is None: mdl = n.zeros_like(im)
+#    # Get the starting residual
+#    inv_ker = n.fft.fft2(ker)
+#    dif = im - n.fft.ifft2(n.fft.fft2(mdl) * inv_ker).real
+#    score = n.sqrt(n.average(dif**2))
+#    a0 = None
+#    n_mdl, n_dif = mdl.copy(), dif.copy()
+#    info = {'success':True, 'term':'maxiter', 'tol':tol}
+#    # Begin the clean loop
+#    for i in range(maxiter):
+#        # Rather than perform a convolution each loop, we'll just subtract
+#        # from the residual a scaled kernel centered on the point just added,
+#        # and to avoid recentering the kernel each time (because clean often
+#        # chooses the same point over and over), we'll buffer the previous one.
+#        a = n.argmax(n_dif)
+#        if a != a0:
+#            a0 = a
+#            rec_ker = recenter(ker, (-a/dim, -a%dim))
+#        v = n_dif.flat[a] / G
+#        n_mdl.flat[a] += v
+#        n_dif -= v * rec_ker
+#        # Check in on how clean is progressing.  Potenially terminate.
+#        if i % chkiter == 0:
+#            # Mystery: why does clean to worse when exact dif is computed?
+#            #n_mdl = n_mdl.clip(lower, upper)
+#            #n_dif = im - n.fft.ifft2(n.fft.fft2(mdl) * inv_ker).real
+#            n_score = n.sqrt(n.average(n_dif**2))
+#            if verbose:
+#                print 'Step %d:' % i, 'score %f,' % n_score, 'best %f' % score
+#            if n_score - score > score * tol:
+#                n_mdl, n_dif = mdl, dif
+#                info['term'] = 'tol'
+#                break
+#            score,mdl,dif = n_score, n_mdl.copy(), n_dif.copy()
+#    info.update({'res':n_dif, 'score': score, 'iter':i+1})
+#    return n_mdl, info
 
 def lsq(im, ker, mdl=None, gain=.1, tol=1e-3, maxiter=200, 
         lower=lo_clip_lev, upper=n.Inf, verbose=False):
